unit uFilterUI;
{$INCLUDE 'Plugin.inc'}

interface

uses
  SysUtils, Classes,
  {$INCLUDE 'DelphiFarUnits.inc'} ,
  uFilter,
  uPluginConsts, uMessages;

type
  TFilterDialog = class(TOkCancelDialog)
  private
    fFilter: TFilter;
    fSaveConfigBeforeUse: boolean;
  private
    fLabelDescription: TFarDialog.TLabel;
    fEditDescription: TFarDialog.TEdit;
    fLabelWildcards: TFarDialog.TLabel;
    fEditWildcards: TFarDialog.TEdit;
    fCheckEditBeforeUse: TFarDialog.TCheckbox;
    fCheckSaveConfigBeforeUse: TFarDialog.TCheckbox;
  protected
    procedure Clear; override;
    procedure CreateUserControls; override;
    procedure ConsoleSizeToDialogSize(var Width, Height: Integer); override;
    procedure SetSize(Width, Height: integer); override;
    procedure FilterToDialog; virtual;
    procedure DialogToFilter; virtual;
    property LabelDescription: TFarDialog.TLabel read fLabelDescription;
    property EditDescription: TFarDialog.TEdit read fEditDescription;
    property LabelWildcards: TFarDialog.TLabel read fLabelWildcards;
    property EditWildcards: TFarDialog.TEdit read fEditWildcards;
    property CheckEditBeforeUse: TFarDialog.TCheckbox read fCheckEditBeforeUse;
    property CheckSaveConfigBeforeUse: TFarDialog.TCheckbox read fCheckSaveConfigBeforeUse;
  public
    constructor Create(GUID: TGUID);
    destructor Destroy; override;
    function Execute: boolean;
    property Filter: TFilter read fFilter write fFilter;
    property SaveConfigBeforeUse: boolean read fSaveConfigBeforeUse write fSaveConfigBeforeUse;
  end;

implementation

{ TFilterDialog }

procedure TFilterDialog.Clear;
begin
  inherited;
  fLabelDescription := nil;
  fEditDescription := nil;
  fLabelWildcards := nil;
  fEditWildcards := nil;
  fCheckEditBeforeUse := nil;
  fCheckSaveConfigBeforeUse := nil;
end;

procedure TFilterDialog.ConsoleSizeToDialogSize(var Width, Height: Integer);
begin
  inherited;
  Height := 11;
end;

constructor TFilterDialog.Create(GUID: TGUID);
begin
  inherited Create(GUID);
end;

procedure TFilterDialog.CreateUserControls;
begin
  inherited;
  fLabelDescription := AddLabel(0, 0, 0, GetMsg(MDescription));
  fEditDescription := AddEdit(0, 0, 0, '');
  fEditDescription.History := 'FilterDescription';
  fLabelWildcards := AddLabel(0, 0, 0, GetMsg(MWildcard));
  fEditWildcards := AddEdit(0, 0, 0, '');
  fEditWildcards.History := 'FilterWildcards';
  fCheckEditBeforeUse := AddCheckbox(0, 0, GetMsg(MEditBeforeUse), False);
  fCheckSaveConfigBeforeUse := AddCheckbox(0, 0, GetMsg(MSaveFilterContent), False);
  fCheckSaveConfigBeforeUse.Visible := False;
end;

destructor TFilterDialog.Destroy;
begin
  inherited;
end;

procedure TFilterDialog.DialogToFilter;
begin
  Filter.Description := EditDescription.Text;
  Filter.FileMaskStr := EditWildcards.Text;
  Filter.EditBeforeUse := CheckEditBeforeUse.Checked;
  Self.SaveConfigBeforeUse := CheckSaveConfigBeforeUse.Checked;
end;

function TFilterDialog.Execute: boolean;
begin
  Result := False;
  FilterToDialog;
  if inherited Execute then
  begin
    DialogToFilter;
    Result := True;
  end;
end;

procedure TFilterDialog.FilterToDialog;
begin
  Frame.Text := Filter.Name;
  EditDescription.Text := Filter.Description;
  EditWildcards.Text := Filter.FileMaskStr;
  CheckEditBeforeUse.Checked := Filter.EditBeforeUse;
  CheckSaveConfigBeforeUse.Checked := Self.SaveConfigBeforeUse;
end;

procedure TFilterDialog.SetSize(Width, Height: integer);
begin
  inherited;
  AutoPos(LabelDescription);
  AutoPos(EditDescription);
  AutoPos(LabelWildcards);
  AutoPos(EditWildcards);
  AutoPos(CheckEditBeforeUse);
  if CheckSaveConfigBeforeUse.Visible then
    CheckEditBeforeUse.Visible := False;
  Autopos(CheckSaveConfigBeforeUse);
end;

end.
